import { StylizedText } from "@/components/StylizedText";
import type React from "react";

export class Language {
    constructor(
        private code: string,
        private translations: { [key: string]: string },
    ) {}

    public getOrDefault(key: string, defaultValue?: string): string {
        return this.translations[key] ?? defaultValue;
    }

    public get(key: string): string {
        return this.getOrDefault(key, key);
    }

    public has(key: string): boolean {
        return key in this.translations;
    }

    public getStyled(key: string, allowMarkown = false): React.ReactNode {
        return <StylizedText markdown={allowMarkown}>{this.get(key)}</StylizedText>;
    }

    public getCode(): string {
        return this.code;
    }
}
