import React from "react";
import { ErrorInfo } from "react";
import { NestedReloadBoundary } from "./ReloadBoundary";

export class FallbackErrorBoundary extends React.Component<any, { error?: any }> {
    constructor(props: { fallback: (e: any) => React.ReactNode; children: React.ReactNode }) {
        super(props);
        this.state = { error: undefined };
    }

    static getDerivedStateFromError(error: any) {
        return { error: error };
    }

    componentDidCatch(error: any, info: ErrorInfo) {
        console.error("The following error was caught by FallbackErrorBoundary:", error, info);
    }

    clearError() {
        this.setState({ error: undefined });
    }

    render() {
        if (this.state.error !== undefined) {
            const myThis = this;
            return (
                <NestedReloadBoundary
                    reloadFunc={() => {
                        myThis.clearError();
                    }}
                >
                    {this.props.fallback(this.state.error)}
                </NestedReloadBoundary>
            );
        }

        return this.props.children;
    }
}
