import { Language } from "@/api/i18n";
import { createContext, useContext, useState, useEffect } from "react";
import { storageGetOrDefault, storageSet } from "@/misc/Storage";

import type React from "react";
import { useBackendContext } from "./BackendProvider";

const EmptyLanguage = new Language("none", {});

const LanguageContext = createContext({
    language: EmptyLanguage,
    setLanguageCode: (set: string | ((i: string | undefined) => string)) => {},
});

function getInitialLanguageCode(): string {
    return storageGetOrDefault("language", "de");
}

export function LanguageProvider({ children }: { children: React.ReactNode }) {
    const [languageCode, setLanguageCode] = useState<string>();
    const [language, setLanguage] = useState(EmptyLanguage);
    const api = useBackendContext();

    useEffect(() => {
        let newLang = languageCode ?? getInitialLanguageCode();
        if (newLang === language.getCode()) return;
        storageSet("language", newLang);

        api.getLanguageFile(newLang)
            .then((translations) => {
                setLanguage(new Language(newLang, translations));
            })
            .catch((error) => {
                console.error(`Exception while loading language ${newLang}:`, error);
                if (newLang !== "de") {
                    setLanguageCode("de");
                }
            });
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [languageCode]);

    return (
        <LanguageContext.Provider value={{ language, setLanguageCode }}>
            {children}
        </LanguageContext.Provider>
    );
}

export function useLanguage() {
    return useContext(LanguageContext);
}
