import { createContext, useContext } from "react";
import type React from "react";

type ReloadFunc = () => void;

const ReloadBoundaryContext = createContext<ReloadFunc>(() => {});

export function ReloadBoundary({
    children,
    reloadFunc,
}: {
    children: React.ReactNode;
    reloadFunc: ReloadFunc;
}) {
    return (
        <ReloadBoundaryContext.Provider value={reloadFunc}>
            {children}
        </ReloadBoundaryContext.Provider>
    );
}

export function NestedReloadBoundary({
    children,
    reloadFunc,
}: {
    children: React.ReactNode;
    reloadFunc: ReloadFunc;
}) {
    const parentReloadFunc = useReloadBoundary();
    return (
        <ReloadBoundaryContext.Provider
            value={() => {
                parentReloadFunc();
                reloadFunc();
            }}
        >
            {children}
        </ReloadBoundaryContext.Provider>
    );
}

export function useReloadBoundary() {
    return useContext(ReloadBoundaryContext);
}
