import { useEffect } from "react";
import { useRouter } from "next/router";

export default function StopNavigation({ warningText }: { warningText: string }) {
    const router = useRouter();
    useEffect(() => {
        const handleWindowClose = (e: BeforeUnloadEvent) => {
            e.preventDefault();
            return warningText;
        };
        const handleBrowseAway = () => {
            if (window.confirm(warningText)) return;
            router.events.emit("routeChangeError");
            throw "routeChange aborted.";
        };
        window.addEventListener("beforeunload", handleWindowClose);
        router.events.on("routeChangeStart", handleBrowseAway);
        return () => {
            window.removeEventListener("beforeunload", handleWindowClose);
            router.events.off("routeChangeStart", handleBrowseAway);
        };
    }, [router, warningText]);
    return null;
}
