import { datetimeToString } from "@/misc/Formatting";
import { useBackendContext } from "./BackendProvider";
import Link from "next/link";
import type { lecture, course } from "@/api/api_v1_types";
import { StylizedText } from "@/components/StylizedText";
import { urlForLecture } from "@/misc/Util";
import { useLanguage } from "./LanguageProvider";
import { LectureLiveLabel } from "./LiveLabel";

export function VideoCard({
    lecture,
    course,
    size,
}: {
    lecture: lecture;
    course: course;
    size?: "small" | "auto";
}) {
    const api = useBackendContext();
    const { language } = useLanguage();
    let dateStr = datetimeToString(lecture.time);

    let sz = size === "small" ? "xxl" : "sm";

    return (
        <Link
            href={urlForLecture(course.id_string, lecture.id)}
            title={course.full_name}
            className="disable-highlight"
        >
            {/* display width >= sz */}
            <div className={`d-none d-${sz}-block`}>
                <div className="row">
                    <img
                        className="col-4"
                        width="170"
                        height="100"
                        style={{
                            maxHeight: "120px",
                            height: "auto",
                            width: "170px",
                        }}
                        src={`${api.assetUrl()}/thumbnail/l_${lecture.id}.jpg`}
                        alt="Vorschaubild"
                    />
                    <div className="col-4">
                        <span>
                            <strong>{course.short_name}</strong>{" "}
                            <LectureLiveLabel lecture={lecture} />
                        </span>{" "}
                        <br />
                        <br />
                        <span>{dateStr}</span>
                        {lecture.speaker ? (
                            <div className="small p-children-inline">
                                {language.get("ui.generic.lecture_given_by")}{" "}
                                <StylizedText markdown>{lecture.speaker}</StylizedText>
                            </div>
                        ) : null}
                    </div>
                    <div className="col-4">
                        <div>
                            <StylizedText markdown>{lecture.title}</StylizedText>
                        </div>
                    </div>
                </div>
            </div>
            {/* display width < sz */}
            <div className={`d-block d-${sz}-none`}>
                <ul className="list-unstyled">
                    <li className="d-flex justify-content-center mb-1">
                        <img
                            width="170"
                            height="100"
                            src={`${api.assetUrl()}/thumbnail/l_${lecture.id}.jpg`}
                            alt="Vorschaubild"
                        />
                    </li>
                    <li>
                        <strong>{course.full_name}</strong>
                        <LectureLiveLabel lecture={lecture} />
                    </li>
                    <li>{dateStr}</li>
                    {lecture.speaker ? (
                        <div className="small p-children-inline">
                            {language.get("ui.generic.lecture_given_by")}{" "}
                            <StylizedText markdown>{lecture.speaker}</StylizedText>
                        </div>
                    ) : null}
                    <li className="disable-last-paragraph-spacing">
                        <StylizedText markdown>{lecture.title}</StylizedText>
                    </li>
                </ul>
            </div>
        </Link>
    );
}
