export function semesterToHuman(semester?: string, long_str?: boolean): string {
    if (!semester || semester === "zeitlos" || semester === "none" || semester.length !== 6) {
        return "Zeitlos";
    }
    const year = semester.substring(0, 4);
    const semesterString = semester.substring(4, 6).toUpperCase();
    if (!year.match(/^\d+$/) || !["SS", "WS"].includes(semesterString)) {
        console.error(`Invalid semester string "${semester}"`);
        return "??";
    }
    if (!long_str) {
        return semesterString + year.substring(2);
    } else if (semesterString === "SS") {
        return `Sommersemester ${year}`;
    } else {
        return `Wintersemester ${year}/${(parseInt(year) + 1).toString().substring(2)}`;
    }
}
export function zeropad(num: number, places: number) {
    var zero = places - num.toString().length + 1;
    return Array(+(zero > 0 && zero)).join("0") + num;
}
export function timestampToString(timestamp: number) {
    let h = zeropad(Math.trunc(timestamp / 3600), 2);
    let m = zeropad(Math.trunc((timestamp % 3600) / 60), 2);
    let s = zeropad(Math.trunc(timestamp % 60), 2);
    let timeasstring = h + ":" + m + ":" + s;
    return timeasstring;
}
export function datetimeToString(datetime: string) {
    let date_parsed = new Date(datetime);
    return `${date_parsed.toLocaleDateString([], { weekday: "short", year: "numeric", month: "2-digit", day: "2-digit" })}, ${date_parsed.toLocaleTimeString([], { hour: "2-digit", minute: "2-digit" })}`;
}
export function filesizeToHuman(size: number) {
    if (size < 1024) {
        return size + " B";
    }
    size /= 1024;
    if (size < 1024) {
        return size.toFixed(1) + " KiB";
    }
    size /= 1024;
    if (size < 1024) {
        return size.toFixed(1) + " MiB";
    }
    size /= 1024;
    return size.toFixed(1) + " GiB";
}
