import { ToastContainer } from "react-toastify";
import "react-toastify/dist/ReactToastify.css";
import { RealBackendProvider } from "@/components/BackendProvider";
import DefaultLayout from "@/components/DefaultLayout";
import { EditModeProvider } from "@/components/EditModeProvider";
import { LanguageProvider } from "@/components/LanguageProvider";
import { ReloadBoundary } from "@/components/ReloadBoundary";
import Title from "@/components/TitleComponent";
import { RealUserProvider } from "@/components/UserDataProvider";
import { showErrorToast } from "@/misc/ErrorHandlers";
import "@/styles/globals.scss";
import type { AppProps } from "next/app";
import Head from "next/head";

export default function App({ Component, pageProps }: AppProps) {
    return (
        <>
            <Head>
                <meta name="viewport" content="width=device-width, initial-scale=1" />
                <link rel="icon" type="image/png" href="/static/favicon.png" sizes="any" />
                <meta
                    name="commit"
                    content={process.env.NEXT_PUBLIC_GIT_COMMIT_HASH ?? "unknown"}
                />
                <meta name="og:site_name" content="VideoAG" />
            </Head>
            <Title title="Video AG" />
            <ReloadBoundary
                reloadFunc={() => {
                    if (process.env.NODE_ENV === "development") {
                        showErrorToast(
                            "Reload boundary without reload! (Application is now in inconsistent state, you should reload)",
                        );
                    } else {
                        window.location.reload();
                    }
                }}
            >
                <RealBackendProvider>
                    <RealUserProvider>
                        <EditModeProvider>
                            <LanguageProvider>
                                <ToastContainer />
                                <DefaultLayout>
                                    <Component {...pageProps} />
                                </DefaultLayout>
                            </LanguageProvider>
                        </EditModeProvider>
                    </RealUserProvider>
                </RealBackendProvider>
            </ReloadBoundary>
        </>
    );
}
