import { Suspense, useEffect, useState } from "react";
import Four04 from "./404";
import CourseListing from "@/components/CourseListing";
import { useBackendContext } from "@/components/BackendProvider";
import { ReloadBoundary } from "@/components/ReloadBoundary";
import { ErrorPage } from "@/misc/ErrorHandlers";
import { ResourceType, fetchDataWrapper } from "@/misc/PromiseHelpers";
import { usePathname } from "next/navigation";
import { useUserContext } from "@/components/UserDataProvider";
import { GetCourseResponse } from "@/api/api_v1_types";
import { FallbackErrorBoundary } from "@/components/FallbackErrorBoundary";

function ActualRedirector() {
    const api = useBackendContext();
    const userContext = useUserContext();
    const hasUserInfo = userContext.hasUserInfo();
    const pathname = usePathname();
    const matchedParams = pathname.match(/^\/([a-z0-9_-]+)\/?$/);
    const [courseData, setCourseData] = useState<ResourceType<GetCourseResponse>>();

    const reload = () => {
        if (!matchedParams) return;
        setCourseData(fetchDataWrapper(api.getCourse(matchedParams[1], true)));
    };

    // eslint-disable-next-line react-hooks/exhaustive-deps
    useEffect(reload, [api, pathname, hasUserInfo]);

    if (!matchedParams) return <Four04 title="Unbekannter Pfad" text="dynamic_course_listing" />;
    if (!courseData) return <></>;

    return (
        <ReloadBoundary reloadFunc={reload}>
            <FallbackErrorBoundary
                fallback={(e: any) => (
                    <ErrorPage
                        error={e}
                        objectName="Kurs"
                        expectedErrorCodes={[
                            "unauthorized",
                            "access_forbidden",
                            "unknown_object",
                            "rate_limited",
                        ]}
                    />
                )}
            >
                <Suspense fallback={<div className="spinner-border" />}>
                    <CourseListing courseData={courseData} />
                </Suspense>
            </FallbackErrorBoundary>
        </ReloadBoundary>
    );
}

export default function DynamicRedirector() {
    // The following is a hack to force nextjs to not pre-render this page at build time (which obv wouldnt make sense)
    const [clientsideForcer, setClientsideForcer] = useState(false);
    useEffect(() => {
        setClientsideForcer(true);
    }, []);

    if (!clientsideForcer) return <></>;

    return <ActualRedirector />;
}
