import Accordion from "react-bootstrap/Accordion";
import type React from "react";

function FaqEntry({
    children,
    id,
    title,
}: {
    id: string;
    children: React.ReactNode;
    title: string;
}) {
    return (
        <Accordion.Item eventKey={id}>
            <Accordion.Header>{title}</Accordion.Header>
            <Accordion.Body>{children}</Accordion.Body>
        </Accordion.Item>
    );
}

export default function FAQ() {
    return (
        <>
            <div className="alert alert-warning alert-dismissible" role="alert" id="kontakt">
                Unter <a href="mailto:video@fsmpi.rwth-aachen.de">video@fsmpi.rwth-aachen.de</a>{" "}
                stehen wir für alle Fragen bereit.
            </div>
            <div className="faqHeader">Allgemein</div>
            <Accordion defaultActiveKey={"xylecture"}>
                <FaqEntry id="xylecture" title="Warum nehmt ihr Vorlesung XY nicht auf?">
                    <p>
                        Zur Aufnahme einer Vorlesung müssen zwei Dinge erfüllt sein: Zum einen muss
                        der Dozent sein Einverständnis geben, zum anderen muss sich jemand finden,
                        der die Vorlesung aufnehmen möchte.
                    </p>
                    <p>
                        Falls du dir wünscht, dass eine Vorlesung von uns aufgenommen wird, melde
                        dich bei uns. Idealerweise schreibst du auch dem Dozenten eine Mail, in der
                        du erläuterst, wie wichtig die Aufnahme für dich wäre. Wir finden dann
                        heraus, ob der Dozent zustimmt.
                    </p>
                    <p>
                        In der Regel hören die AGler, die eine Vorlesung filmen, diese selber. Es
                        kann daher gut sein, dass sich bei uns niemand findet. In dem Fall sind wir
                        auf deine Mithilfe angewiesen. Solltest du Lust haben mitzumachen, melde
                        dich bei uns!
                    </p>
                </FaqEntry>
                <FaqEntry id="speed" title="Wieso ist der Download so langsam?">
                    <p>
                        Wir beschränken die Downloadgeschwindigkeit nicht! Eventuell hast du im
                        Uninetz eine bessere Anbindung.
                    </p>
                    <p>
                        Falls du unbedingt einen <strong>Download-Manager</strong> benutzen
                        willst/musst, stelle diesen bitte so ein, dass er maximal{" "}
                        <strong>5 gleichzeitige Verbindungen</strong> (oder auch weniger) zu unserem
                        Videoserver benutzt.
                    </p>
                    <p>
                        Unser Server hat keine (nein, absolut keine!) Bandbreitenbegrenzung, also
                        bekommst du schon für einen einzigen Download die volle Geschwindigkeit und
                        wirst selbst mit solchen Programmen keine schnelleren Downloads erfahren. Zu
                        viele Verbindungen sorgen nur für exzessive Systemlast und damit langsamere
                        Downloads für alle, dich eingeschlossen.
                    </p>
                </FaqEntry>
                <FaqEntry
                    id="duration"
                    title="Wieso dauert das so lange, bis Videos verfügbar sind?"
                >
                    <p>
                        Bis wir ein Video veröffentlichen können, ist erst noch eine Bearbeitung
                        notwendig, der "Schnitt". Zuerst müssen die Rohdaten auf den jeweiligen
                        Rechner, auf dem geschnittten wird, kopiert werden. Pro Vorlesung fallen
                        mindestens 20GB an Daten an, oft auch gerne mal das doppelte oder
                        mehr.Teilweise ist noch entpacken, transcodieren oder sonstiges bearbeiten
                        der einzelnen Dateien nötig, bevor sie für Premiere (der Software von Adobe,
                        die wir für den Schnitt verwenden) lesbar sind und unseren eigenen
                        Ansprüchen genügen.
                    </p>
                    <p>
                        Dann erst beginnt der eigentliche Schnitt. Dieser kann weniger als eine
                        Stunde dauern, manchmal aber auch um vieles mehr. Das hängt unter Anderem
                        davon ab, wie viele zu synchronisierende Medien verwendet werden, ob wir die
                        Audiodateien oder die Farben der Kameraaufzeichnungen nachträglich
                        korrigieren bzw manuell Folien einfügen müssen, ob Overheadprojektoren
                        verwendet werden (deren Aufnahme ist oft ohne langwieriger Bearbeitung nicht
                        sinnvoll lesbar) und und und...
                    </p>
                    <p>
                        Wenn wir dann schließlich mit dem bearbeiteten Video zufrieden sind, muss es
                        noch konvertiert werden, damit es so abspielbar ist, wie ihr es von unseren
                        Videos gewohnt seid. Dies dauert ohne aufwändige Bearbeitungen auf unseren
                        Schnittrechnern in etwa so lang, wie auch die Veranstaltung geht. Wenn
                        allerdings Bearbeitungen gemacht wurden, kann ein Video gern auch mal 20
                        Stunden im Encoder verbringen. Schließlich veröffentlichen wir dann das
                        fertige Video auf unserer Website.
                    </p>
                    <p>
                        Es kann immer mal passieren, dass in einer Vorlesung etwas schief läuft und
                        einzelne Videos viel zeitaufwändiger sind als die anderen in einer
                        Veranstaltungsreihe. Wir versuchen, über die Textfelder innerhalb der
                        Terminliste der zugehörigen Veranstaltung mit euch zu kommunizieren und euch
                        Informationen zu den (noch nicht) hochgeladenen Videos zu geben.
                    </p>
                    <p>
                        Bitte behaltet im Hinterkopf, dass wir genauso Studenten wie ihr seid. Wir
                        haben einen genauso vollen Terminkalender und engagieren uns ehrenamtlich,
                        damit wir euch die Vorlesungsvideos zur Verfügung stellen können. Im
                        Normalfall sollte dies binnen einer Woche geschehen. Manchmal kann es aber
                        auch passieren, dass die Zuständigen der jeweiligen Veranstaltung eine
                        besonders stressige Woche haben oder einfach auch mal krank werden. Bitte
                        habt Verständnis dafür, wenn dann einzelne Videos nicht so schnell wie sonst
                        hochgeladen werden.
                    </p>
                    <p>
                        Generell gilt: Wenn wir euch bereits Termine einer Veranstaltung zur
                        Verfügung gestellt haben, dann muss schon sehr viel schief gehen, dass wir
                        das nicht fortführen. Ihr könnt also davon ausgehen, dass die fehlenden
                        Videos in Bearbeitung sind und ebenfalls demnächst hochgeladen werden.
                    </p>
                </FaqEntry>
            </Accordion>

            <div className="faqHeader">Abspielprobleme</div>
            <Accordion>
                <FaqEntry id="permissions" title="Wieso kann ich einzelne Videos nicht abspielen?">
                    <p>
                        Auf Wunsch der Dozenten schränken wir den Zugriff auf Videos vieler
                        Veranstaltungen ein. In der Regel ist dies eine Vorraussetzung dafür, dass
                        wir eine Vorlesung überhaupt aufnehmen dürfen.
                    </p>
                    <p>
                        Wer auf ein bestimmtes Videos zugreifen kann, wird auf der
                        Veranstaltungsseite durch Symbole auf der rechten Seite angezeigt. Dabei
                        gibt es folgende Möglichkeiten:
                    </p>
                    <ul>
                        <li>
                            <strong>Öffentliche</strong> Videos (
                            <span className="bi bi-globe"></span>) können von jedem abgespielt
                            werden.
                        </li>
                        <li>
                            <strong>RWTH-interne</strong> Videos (
                            <span className="icon-rwth"></span>) sind nur für RWTH-Angehörige
                            verfügbar. Zum Anschauen ist eine Authentifizierung über das
                            RWTH-Single-Sign-On nötig.
                        </li>
                        <li>
                            <strong>Lernraum-interne</strong> Videos (
                            <span className="icon-moodle"></span>) sind nur für Teilnehmer eines
                            bestimmten Moodle-Lernraums zugänglich. Wir überprüfen dies, indem du
                            uns kurzzeitig Zugriff auf deinen Moodle-Account gibst, aus dem wir die
                            Liste deiner Lernräume auslesen. Solltest du eine Vorlesung hören, dem
                            zugehörigen Lernraum aber nicht hinzugefügt worden sein, melde dich
                            bitte beim entsprechenden Dozenten.
                        </li>
                        <li>
                            <strong>Passwort-geschützte</strong> Videos (
                            <span className="bi bi-lock-fill"></span>) sind nur nach Eingabe eines
                            Passworts verfügbar, welches jedem zur Verfügung gestellt wurde, der
                            Zugriff haben sollte. In der Regel gibt es gute Gründe, warum dieser
                            Zugriffsschutz gewählt wurde.
                        </li>
                    </ul>
                    <p>
                        Falls du keinen Zugriff auf ein Video hast, wird dies auf der Player-Seite
                        angezeigt und ggf. auf die weiteren Schritte zur Authentifizierung
                        verwiesen. Die erläuterten Möglichkeiten decken nicht jeden denkbaren Fall
                        ab. Solltest du Zugriff auf eine Veranstaltung benötigen, aber aus
                        irgendwelchen Gründen nicht haben, schreib uns eine Mail.
                    </p>
                </FaqEntry>
                <FaqEntry
                    id="playback"
                    title="Ich kann ein heruntergeladenes Video nicht abspielen."
                >
                    <p>
                        Unsere neueren Videos sind nach MPEG 4 AVC (H.264) kodiert. Diese Kodierung
                        produziert gute Bildqualität und spart Platz. Außerdem sollten unsere Videos
                        so in den meinsten Playern funktionieren.
                    </p>
                    <p>
                        Ein beliebter Videoplayer ist VLC, denn er kann so ziemlich alle üblichen
                        Audio- und Videoformate abspielen. VLC gibt es unter{" "}
                        <a href="https://www.videolan.org">https://www.videolan.org</a> zum
                        Download.
                    </p>
                    <p>
                        Wenn du Windows Media Player oder ähnliches benutzt, fehlen eventuell nötige
                        Codecs. Am einfachsten installierst du{" "}
                        <a href="http://de.wikipedia.org/wiki/Ffdshow">ffdshow</a> (
                        <a href="http://sourceforge.net/projects/ffdshow-tryout/">
                            ffdshow download
                        </a>
                        ). ffdshow ist eine Sammlung von{" "}
                        <a href="http://de.wikipedia.org/wiki/Codec">Codecs</a> zusammengefasst
                        unter einer Oberfläche. Wenn du ffdshow installiert hast, solltest du unsere
                        neueren Videos in so ziemlich jedem Player abspielen können.
                    </p>
                    <p>Sollte das nicht helfen, schreib uns bitte an.</p>
                </FaqEntry>
            </Accordion>
            <div className="faqHeader">Technisches</div>
            <Accordion>
                <FaqEntry
                    id="l2prights"
                    title="Warum benötigt ihr lesenden und schreibenden Zugriff auf meine L2P oder Moodle-Lernräume?"
                >
                    <p>
                        Auf vielfachen Wunsch unserer Dozenten haben wir die Möglichkeit umgesetzt,
                        Videos nur für Teilnehmer eines bestimmten L2P- oder Moodle-Lernraums
                        zugänglich zu machen. Um dies umzusetzen benötigen wir die Liste der
                        Lernräume eines Nutzers, und damit Zugriff auf den L2P- oder Moodle-Account.
                        Leider erlaubt uns das L2P sowie Moodle nur entweder keinen oder vollen
                        (also lesenden und schreibenden) Zugriff, sodass du uns zur
                        Authentifizierung für Lernraum-interne Videos mehr Zugriffsrechte geben
                        musst, als theoretisch nötig.
                    </p>
                    <p>
                        Um die Missbrauchsgefahr zu minimieren, widerrufen wir die Zugriffsrechte
                        auf deine Lernräume, sobald wir die Liste der Lernräume abgerufen haben. Du
                        kannst dies <a href="https://oauth.campus.rwth-aachen.de/manage/">hier</a>{" "}
                        überprüfen. Außerdem speichern wir keine Authentifikationsdaten auf unserem
                        Server.
                    </p>
                    <p>
                        Details zu der dafür verwendeten Schnittstelle findest du in der{" "}
                        <a href="https://www3.elearning.rwth-aachen.de/_vti_bin/L2PServices/api.svc/v1/Documentation">
                            L2P-API-Dokumentation
                        </a>{" "}
                        und der{" "}
                        <a href="https://moped.ecampus.rwth-aachen.de/proxy/api/v2/documentation">
                            Moodle-API-Dokumentation
                        </a>
                        .
                    </p>
                </FaqEntry>
                <FaqEntry id="cookies" title="Welche Cookies werden gesetzt und wofür?">
                    <p>
                        Beim reinen Betrachten der Seite setzen wir überhaupt keine Cookies. Einzig
                        beim Abruf oder Abspielen von Videodateien und bei der Authentifizierung für
                        RWTH- oder Lernraum-interne Videos werden Cookies gesetzt.
                    </p>
                    <p>
                        Das <code>tracking</code>-Cookie erleichtert uns das Erheben von
                        Abrufstatistiken zu unseren Videos. Diese werden immer wieder von Dozenten
                        gefordert, aber auch wir haben ein großes Interesse daran zu wissen, wofür
                        sich unsere Studierenden interessieren. Wird das Cookie nicht zugelassen
                        werden unsere Statistiken ungenau, allerdings bleibt die Website
                        uneingeschränkt nutzbar.
                    </p>
                    <p>
                        Anders sieht dies beim <code>session</code>-Cookie aus. Für die
                        Authentifizierung ist es notwendig dieses zuzulassen, da wir alle nötigen
                        Daten (OAuth-Tokens, Zugriffsrechte) in diesem Cookie und nicht auf unserem
                        Server speichern. Das Cookie ist kryptographisch gesichert und enthält nur
                        die zum jeweiligen Zeitpunkt nötigen Daten.
                    </p>
                    <p>
                        In keinem Fall erstellen wir auf Basis der gespeicherten Daten
                        Nutzerprofile.
                    </p>
                </FaqEntry>
            </Accordion>
            <div className="faqHeader">Video Player</div>
            <Accordion>
                <FaqEntry id="playershortcuts" title="Welche Shortcuts gibt es für den Player?">
                    <p>Es gibt folgende Shortcuts um den Player mit der Tastatur zu Steuern:</p>
                    <ul>
                        <li>
                            <strong>Space</strong> um das Video zu Pausieren.
                        </li>
                        <li>
                            <strong>Pfeiltasten Links/Rechts</strong> um im Video 15 Sekunden zurück
                            oder vorzuspulen.
                        </li>
                        <li>
                            <strong>Pfeiltasten Hoch/Runter</strong> um die Lautstärke zu erhöhen
                            oder zu veringern.
                        </li>
                        <li>
                            <strong>M</strong> um das Video auf Stumm zu stellen.
                        </li>
                        <li>
                            <strong>F</strong> um das Video im Fullscreen anzuzeigen.
                        </li>
                        <li>
                            <strong>0-9</strong> um zur x Prozent Marke des Videos zu Springen. So
                            springt man zum Beispiel mit 5 zur Hälfte des Videos.
                        </li>
                    </ul>
                </FaqEntry>
                <FaqEntry
                    id="embedding"
                    title="Wie kann ich Videos auf anderen Webseiten einbetten?"
                >
                    <p>
                        Unter jedem Video befindet sich auf der rechten Seite ein
                        „Einbetten“-Button. Wenn du diesen Button anklickst, wird ein Einbettcode
                        angezeigt, mit dem du das Video in eine andere Webseite einbetten kannst.
                    </p>
                    <p>
                        <strong>Einbettung in Moodle-Lernräumen:</strong> Der Einbettcode kann auch
                        auf Textseiten in RWTHmoodle eingefügt werden. Dazu muss zuerst die
                        Menüleiste des Editors über den Button „Menüleiste umschalten“ bzw. „Mehr
                        Symbole anzeigen“ (erkennbar am einem Pfeil-Symbol) umgeschaltet werden.
                        Danach wird der Button „HTML“ (<code>&lt;/&gt;</code>) sichtbar, über den
                        der Editor in den HTML-Modus umgeschaltet werden muss. Danach kann der
                        Einbettcode an der gewünschten Stelle eingefügt werden.
                    </p>
                </FaqEntry>
            </Accordion>
        </>
    );
}
