import { useBackendContext } from "@/components/BackendProvider";
import ModeratorBarrier from "@/components/ModeratorBarrier";
import { ReloadBoundary } from "@/components/ReloadBoundary";
import { useFilteredDataView, PagingNavigation } from "@/components/FilteredData";
import { DateTime } from "luxon";
import { ErrorPage } from "@/misc/ErrorHandlers";

import type { GetFeedbackResponse, int } from "@/api/api_v1_types";

function FeedbackList({
    feedback,
    setFilter,
}: {
    feedback: GetFeedbackResponse;
    setFilter: (
        key: string,
        new_value: any | undefined,
        isValid: boolean,
        updateNow: boolean,
    ) => void;
}) {
    return (
        <>
            <div className="table-responsive">
                <table className="table table-hover" style={{ tableLayout: "fixed" }}>
                    <thead>
                        <tr>
                            <th scope="col" style={{ width: "11em" }}>
                                Zeit
                            </th>
                            <th scope="col" style={{ width: "15em" }}>
                                Email
                            </th>
                            <th scope="col">Text</th>
                        </tr>
                    </thead>
                    <tbody>
                        {(feedback?.page ?? []).map((i) => {
                            const formattedDate = DateTime.fromISO(i.time_created).toFormat(
                                "yyyy-MM-dd HH:mm:ss",
                            );
                            return (
                                <tr key={i.id}>
                                    <td>{formattedDate}</td>
                                    <td>{i.email ?? ""}</td>
                                    <td>{i.text}</td>
                                </tr>
                            );
                        })}
                    </tbody>
                </table>
            </div>
        </>
    );
}

function FeedbackImpl() {
    const api = useBackendContext();
    const { filters, setFilter, reloadData, isLoading, data, error } = useFilteredDataView(
        (filters) =>
            api.getFeedback({
                entries_per_page: filters.get("entries_per_page") as int | undefined,
                page: filters.get("page") as int | undefined,
            }),
    );
    return (
        <div className="card">
            <div className="card-header d-flex">Feedback</div>
            <div className="card-body">
                <p>Hier werden alle gesendeten Feedbacks angezeigt</p>
                <ReloadBoundary reloadFunc={reloadData}>
                    <div className="d-flex">
                        <PagingNavigation
                            setFilter={setFilter}
                            filters={filters}
                            pageCount={data?.page_count}
                        />
                        {isLoading && <div className="spinner-border ms-3 mt-1" />}
                    </div>
                    {error ? (
                        <ErrorPage error={error} objectName="Feedback" showButtons={false} />
                    ) : (
                        data && <FeedbackList feedback={data} setFilter={setFilter} />
                    )}
                </ReloadBoundary>
            </div>
        </div>
    );
}

export default function Feedback() {
    return (
        <ModeratorBarrier>
            <FeedbackImpl />
        </ModeratorBarrier>
    );
}
